@@ -13,8 +13,8 @@ sub moos {
                              < Moo! > < !ooM >
                               ------   ------
                      ^__^   /                 \   ^__^
-             _______/(oo)  /                   \  (oo)\_______
-         /\/( ingy  /(__)                         (__)\  mst  )\/\
+             _______/(öö)  /                   \  (oo)\_______
+         /\/( ingy  /(__)                         (__)\  tsm  )\/\
             | w----||                              /  ||----w |
             ||     ||                                 ||     ||
 EOEOMOO
